@@ -3,7 +3,7 @@ use strict;
 use warnings;
 package Email::Simple;
 # ABSTRACT: simple parsing of RFC2822 message format and headers
-$Email::Simple::VERSION = '2.208';
+$Email::Simple::VERSION = '2.211';
 use Carp ();
 
 use Email::Simple::Creator;
@@ -76,7 +76,7 @@ sub new {
 
   Carp::croak 'Unable to parse undefined message' if ! defined $text;
 
-  my $text_ref = ref $text ? $text : \$text;
+  my $text_ref = (ref $text || '' eq 'SCALAR') ? $text : \$text;
 
   my ($pos, $mycrlf) = $class->_split_head_from_body($text_ref);
 
@@ -109,14 +109,18 @@ sub _split_head_from_body {
   my ($self, $text_ref) = @_;
 
   # For body/header division, see RFC 2822, section 2.1
-  my $crlf = $self->__crlf_re;
+  #
+  # Honestly, are we *ever* going to have LFCR messages?? -- rjbs, 2015-10-11
+  my $re = qr{\x0a\x0d\x0a\x0d|\x0d\x0a\x0d\x0a|\x0d\x0d|\x0a\x0a};
 
-  if ($$text_ref =~ /(?:.*?($crlf))\1/gsm) {
-    return (pos($$text_ref), $1);
+  if ($$text_ref =~ /($re)/gsm) {
+    my $crlf = substr $1, 0, length($1)/2;
+    return (pos($$text_ref), $crlf);
   } else {
 
     # The body is, of course, optional.
-    $$text_ref =~ /($crlf)/gsm;
+    my $re = $self->__crlf_re;
+    $$text_ref =~ /($re)/gsm;
     return (undef, ($1 || "\n"));
   }
 }
@@ -333,7 +337,7 @@ Email::Simple - simple parsing of RFC2822 message format and headers
 
 =head1 VERSION
 
-version 2.208
+version 2.211
 
 =head1 SYNOPSIS
 
@@ -494,9 +498,7 @@ for subclassing.  The default default is Email::Simple::Header.
 Email::Simple handles only RFC2822 formatted messages.  This means you cannot
 expect it to cope well as the only parser between you and the outside world,
 say for example when writing a mail filter for invocation from a .forward file
-(for this we recommend you use L<Email::Filter> anyway).  For more information
-on this issue please consult RT issue 2478,
-L<http://rt.cpan.org/NoAuth/Bug.html?id=2478>.
+(for this we recommend you use L<Email::Filter> anyway).
 
 =head1 AUTHORS
 
@@ -518,7 +520,7 @@ Ricardo SIGNES
 
 =head1 CONTRIBUTORS
 
-=for stopwords Brian Cassidy Christian Walde Michael Stevens Ricardo SIGNES Signes Ronald F. Guilmette William Yardley
+=for stopwords Brian Cassidy Christian Walde Michael Stevens Pali Ricardo SIGNES Ronald F. Guilmette William Yardley
 
 =over 4
 
@@ -536,11 +538,11 @@ Michael Stevens <mstevens@etla.org>
 
 =item *
 
-Ricardo SIGNES <rjbs@cpan.org>
+Pali <pali@cpan.org>
 
 =item *
 
-Ricardo Signes <rjbs@cpan.org>
+Ricardo SIGNES <rjbs@cpan.org>
 
 =item *
 
@@ -568,8 +570,6 @@ __END__
 #pod Email::Simple handles only RFC2822 formatted messages.  This means you cannot
 #pod expect it to cope well as the only parser between you and the outside world,
 #pod say for example when writing a mail filter for invocation from a .forward file
-#pod (for this we recommend you use L<Email::Filter> anyway).  For more information
-#pod on this issue please consult RT issue 2478,
-#pod L<http://rt.cpan.org/NoAuth/Bug.html?id=2478>.
+#pod (for this we recommend you use L<Email::Filter> anyway).
 #pod
 #pod =cut
